#Dart croc v2 incl HC samples for small populations

#Install dartR package

#install.packages('dartR', repos='http://cran.us.r-project.org').

setwd("C:/UserData/bankss/Crocodiles/Cobourg croc paper genetic analyses/Report-DCroc17-2955")

require(dartR)

dartcroc2r<-gl.read.dart("Report_DCroc17-2955_1_moreOrders_SNP_singlerow_1_Cob_paper.csv", covfilename = "idpop_file_regions.csv", nas = "-", topskip = NULL,
lastmetric = "RepAvg", probar = TRUE)

#Call rate
gl.report.callrate(dartcroc2r, method = "loc")
#Retain >95%
dartcroc22r<-gl.filter.callrate(dartcroc2r, method = "loc", threshold = 0.95)

#RepAvg
gl.report.repavg(dartcroc22r)
#Retain >95%
dartcroc23r<-gl.filter.repavg(dartcroc22r, t = 0.95)

#MAF
gl.report.maf(dartcroc23r, plot=TRUE)
#dartcroc23r_b<-gl.filter.maf(dartcroc23r, threshold = 0.05)

#Secondaries
gl.report.secondaries(dartcroc23r)
dartcroc24r<-gl.filter.secondaries(dartcroc23r)

#Ho calc
require(parallel)
gl.report.heterozygosity(dartcroc24r)
#gl.report.hwe(dartcroc24r)
#gl.hwe.pop(dartcroc24r, pvalue = 0.05, plot = TRUE)

#PCoA

dc4_pcoar<-gl.pcoa(dartcroc24r, nfactors = 5, v = TRUE, parallel = FALSE)
save(dc4_pcoar,file="dc4r_pcoa.RData")
#load("dc4_pcoa.RData")

#3d plot

gl.pcoa.plot.3d(dc4_pcoar, dartcroc24r, title = "PCoA", xaxis = 1, yaxis = 2, zaxis = 3,
shape = "sphere", radius = 2, legend = "topright")

#2D plot 1v2
gl.pcoa.plot(dc4_pcoar, dartcroc24r, scale = FALSE, ellipse = FALSE, p = 0.95,
labels = "pop", hadjust = 1.5, vadjust = 1, xaxis = 1, yaxis = 2)

#2D plot 1v3
gl.pcoa.plot(dc4_pcoar, dartcroc24r, scale = FALSE, ellipse = FALSE, p = 0.95,
labels = "pop", hadjust = 1.5, vadjust = 1, xaxis = 1, yaxis = 3)

#2D plot 2v3
gl.pcoa.plot(dc4_pcoar, dartcroc24r, scale = FALSE, ellipse = FALSE, p = 0.95,
labels = "pop", hadjust = 1.5, vadjust = 1, xaxis = 2, yaxis = 3)

#pop pcoa
dc4_pcoa_pop<-gl.pcoa.pop(dartcroc24r, c = "none", method = "euclidean")
dc4_pcoa_pop$eig
dc4_pcoa_pop$scores

#plot pop PCA
pal=c("black", "red", "green", "yellow", "blue", "orange", "purple", "lightgreen")
plot(dc4_pcoa_pop$scores, col=pal,pch=19, cex=2)
#text(dc4_pcoa_pop$scores[,1],dc4_pcoa_pop$scores[,2], row.names(dc4_pcoa_pop$scores), cex=0.6, pos=4, col="red") 
legend("bottomright", title="Region", legend=rownames(dc4_pcoa_pop$scores), fill=pal,bty="n")


#Fst estimation
#install.packages('StAMPP', repos='http://cran.us.r-project.org')
library(StAMPP)
pwfst <-stamppFst(dartcroc24r, nboots=100, percent=95, nclusters=1)
round(pwfst,3)
pwfst$Pvalues
pwfst$Bootstraps
write.csv(pwfst,"fstout_smallpops regions.csv")











########################################
SNPrelate
#################################
gl2gds(dartcroc24r, outfile = "dartcroc24r.gds")

#Install SNPrelate
#source("https://bioconductor.org/biocLite.R")
#biocLite("SNPRelate")

require(SNPRelate)
require(gdsfmt)

genofile <- snpgdsOpen("dartcroc24r.gds")

snplist1<-snpgdsSelectSNP(genofile, sample.id=NULL, snp.id=NULL, remove.monosnp=TRUE, maf=0.05, missing.rate=0.1, verbose=TRUE)
length(snplist1)

#SNPRelate PCA
pca <- snpgdsPCA(genofile, num.thread=2, snp.id=snplist1)
pc.percent <- pca$varprop*100
head(round(pc.percent, 2))

popcodes<-read.csv("idpop_file_regions.csv")
popcodes<-popcodes[,c(1,3)]
tab <- data.frame(sample.id = popcodes$id,
    pop = factor(popcodes$smallpop),
    EV1 = pca$eigenvect[,1],    # the first eigenvector
    EV2 = pca$eigenvect[,2],    # the second eigenvector
    stringsAsFactors = FALSE)
head(tab)

#PLot it
plot(tab$EV2, tab$EV1, col=as.integer(tab$pop), pch=19, xlab="eigenvector 2", ylab="eigenvector 1")
legend("bottomleft", legend=levels(tab$pop), pch=19, bty="n")

#PLot 1st 4 PC's
lbls <- paste("PC", 1:4, "\n", format(pc.percent[1:4], digits=2), "%", sep="")
pairs(pca$eigenvect[,1:4], col=tab$pop, labels=lbls)


#Relatedness using MoM
sample.id <- read.gdsn(index.gdsn(genofile, snp.id=snplist1))

ibd1 <- snpgdsIBDMoM(genofile, maf=0.05, missing.rate=0.05, num.thread=2)

ibd.coeff1 <- snpgdsIBDSelection(ibd1)
head(ibd.coeff1)
write.csv(ibd.coeff1,file="SNPrelate_ibd_MoM_all.csv")

plot(ibd.coeff1$k0, ibd.coeff1$k1, xlim=c(0,1), ylim=c(0,1),
    xlab="k0", ylab="k1", main="Top End (MoM)")
lines(c(0,1), c(1,0), col="red", lty=2)


#Relatedness using MLE
ibd2 <- snpgdsIBDMLE(genofile, maf=0.05, missing.rate=0.1, num.thread=2)
ibd.coeff2 <- snpgdsIBDSelection(ibd2)
write.csv(ibd.coeff2,file="SNPrelate_ibd_MLE_allr.csv")

plot(ibd.coeff2$k0, ibd.coeff2$k1, xlim=c(0,1), ylim=c(0,1),
    xlab="k0", ylab="k1", main="MLE")
lines(c(0,1), c(1,0), col="red", lty=2)

#KING MoM
ibd.robust <- snpgdsIBDKING(genofile, num.thread=2, snp.id=snplist1)
names(ibd.robust)
ibd.coeff3 <- snpgdsIBDSelection(ibd.robust)
write.csv(ibd.coeff3,file="SNPrelate_ibd_Robust_allr.csv")


dat <- snpgdsIBDSelection(ibd.robust)
head(dat)
plot(dat$IBS0, dat$kinship, xlab="Proportion of Zero IBS",
    ylab="Estimated Kinship Coefficient (KING-robust)")

#Inbreeding coefficients
inb1<-snpgdsIndInb(genofile, maf=0.05, snp.id=snplist1, method=c("mom.weir", "mom.visscher", "mle"), allele.freq=NULL,
out.num.iter=TRUE, reltol=.Machine$double.eps^0.75, verbose=TRUE)

inb_TopEnd<-snpgdsIndInb(genofile, snp.id=snplist1, maf=0.05, method=c("mom.weir", "mom.visscher", "mle"), allele.freq=NULL,
out.num.iter=TRUE, reltol=.Machine$double.eps^0.75, verbose=TRUE)
inbr_out<-cbind(TopEnd.id,inb_TopEnd$inbreeding)
write.csv(inbr_out,file="TopEnd_inbreeding_coeffr.csv")
hist(inb_TopEnd$inbreeding)

#Try IBS for exploratory stuff
ibs <- snpgdsIBS(genofile, snp.id=snplist1, num.thread=2)
write.csv(ibs$ibs,file="SNPrelate_ibs_allr.csv")
ibs$ibs[1:10,1:10]

pop.idx <- order(popcodes$smallpop)
image(ibs$ibs[pop.idx, pop.idx], col=terrain.colors(16))
# HWE test
p <- snpgdsHWE(genofile, snp.id=snplist1)
summary(p)
# QQ plot
plot(-log10((1:length(p))/length(p)), -log10(p[order(p)]),
xlab="-log10(expected P)", ylab="-log10(observed P)", main="QQ plot")
abline(a=0, b=1, col="blue")


#Missing samples
missrate<-snpgdsSampMissRate(genofile, snp.id=NULL, with.id=FALSE)
outmiss<-cbind(TopEnd.id,missrate)
write.csv(outmiss,file="TopEnd_inbreeding_coeff2.csv")

snpgdsIBSNum(genofile, snp.id = snplist1, verbose = TRUE)
popcodes
snpgdsSummary(genofile)

diss1<-snpgdsDiss(genofile, snp.id=snplist1)
diss1$diss

snpgdsFst(genofile, population=popcodes$smallpop, method=c("W&C84", "W&H02"), sample.id=NULL,
snp.id=snplist1)

